/******************************************************************************/
/* Files to Include                                                           */
/******************************************************************************/

#if defined(__XC)
    #include <xc.h>         /* XC8 General Include File */
#elif defined(HI_TECH_C)
    #include <htc.h>        /* HiTech General Include File */
#endif

#include <stdint.h>        /* For uint8_t definition */
#include <stdbool.h>       /* For true/false definition */

#include "system.h"        /* System funct/params, like osc/peripheral config */
#include "user.h"          /* User funct/params, such as InitApp */

/******************************************************************************/
/* User Global Variable Declaration                                           */
/******************************************************************************/

/* i.e. uint8_t <variable_name>; */

/******************************************************************************/
/* Main Program                                                               */
/******************************************************************************/
void main(void)
{
    /* Configure the oscillator for the device */
    ConfigureOscillator();

    /* Initialize I/O and Peripherals for application */
    InitApp();


    while(1)
    {
        switch(LockState)
        {
            case LOCKED:
                if(UnlockMessage)
                {
                    // TODO: set PWM to unlocked position
                    // start timer
                    T0IE = 1; // enable PWM
                    LockState = UNLOCKING;
                    UnlockMessage = false;
                }
                break;
            case UNLOCKING:
                if(DoneMoving) // timer finished
                {
                    T0IE = 0; // disable PWM
                    LockState = UNLOCKED;
                    DoneMoving = false;
                    LED_PIN = 0;
                }
                break;
            case UNLOCKED:
                if(LockMessage)
                {
                    // TODO: set PWM to locked position
                    // start timer
                    T0IE = 1; // enable PWM
                    LockState = LOCKING;
                    LockMessage = false;
                }
                break;
            case LOCKING:
                if(DoneMoving)
                {
                    T0IE = 0;  //disable PWM
                    LockState = LOCKED;
                    DoneMoving = false;
                    LED_PIN = 1;
                }
                break;
            default:
                break;
        }
    }
}